pub struct Program {
pub pipelines: Vec<Pipeline>,
}Expand description
The root of a parsed slash-command program.
A program is a sequence of Pipelines connected by && / || operators.
The operator stored on each pipeline indicates how it connects to the next one.
Fields
pipelines: Vec<Pipeline>Trait Implementations
impl StructuralPartialEq for Program